C***********************************************************************
C***********************************************************************
C**
C** INTEGRAL SYSTEMS, INC.
C**
C***********************************************************************
C**
C** PROJECT : OPERATIONS GROUND EQUIPMENT FOR GOES-NEXT
C** SYSTEM : EARTH LOCATION USERS GUIDE
C** ROUTINE : GATT
C** SOURCE : GATT.FOR
C** LOAD NAME : ANY
C** PROGRAMMER: IGOR LEVINE
C**
C** VER. DATA BY COMMENT
C** ---- -------- --- ---------------------------------------------
C** A 12/01/88 IL INITIAL CREATION
C**
C***********************************************************************
C**
C** THIS FUNCTION COMPUTES AN ATTITUDE/MISALIGNMENT ANGLE FROM A
C** GIVEN SUBSET OF THE O&A PARAMETERS IN GVAR BLOK 0.
C** ARGUMENT K0 INDICATES THE FIRST WORD OF THE SUBSET.
C**
C***********************************************************************
C**
C** CALLED BY : LMODEL
C** COMMONS MODIFIED: NONE
C** INPUTS : NONE
C** OUTPUTS : NONE
C** ROUTINES CALLED : NONE
C**
C***********************************************************************
C***********************************************************************
      REAL*4 FUNCTION GATT(K0,REC,WA,TE)
      IMPLICIT NONE
C
C CALLING PARAMETERS
C
      INTEGER K0
C STARTING POSITION OF A PARAMETER SUBSET IN THE
C O&A SET
      REAL*4 REC(336)
C INPUT O&A PARAMETER SET
      REAL WA
C INPUT SOLAR ORBIT ANGLE IN RADIANS
      REAL TE
C INPUT EXPONENTIAL TIME DELAY FROM EPOCH (MINUTES)
C
C LOCAL VARIABLES
C
      INTEGER*4 I,J,M,L,LL,K
      REAL*4 IR,JR,MR,ATT
      EQUIVALENCE (I,IR),(J,JR),(M,MR)
C
C INCLUDE FILES
C
C***********************************************************************
C
C CONSTANT COMPONENT
C
      K=K0
      ATT=REC(K+2)
C
C COMPUTES THE EXPONENTIAL TERM
C
      IF (TE.GE.0.AND.REC(K+1).GT.0.) ATT=ATT+REC(K)*EXP(-TE/REC(K+1))
C
C EXTRACTS THE NUMBER OF SINUSOIDS
C
      IR=REC(K+3)
C
C CALCULATION OF SINUSOIDS
C
      DO 10 L=1,I
      ATT=ATT+REC(K+2*L+2)*COS(WA*L+REC(K+2*L+3))
   10 CONTINUE
C
C POINTER TO THE NUMBER OF MONOMIAL SINUSOIDS
C
      K=K+34
C
C EXTACTS NUMBER OF MONOMIAL SINUSOIDS
C
      IR=REC(K)
C
C COMPUTES MONOMIAL SINUSOIDS
C
      DO 20 L=1,I
      LL=K+5*L
C
C ORDER OF SINUSOID
C
      JR=REC(LL-4)
C
C ORDER OF MONOMIAL SINUSOID
C
      MR=REC(LL-3)
      ATT=ATT+REC(LL-2)*((WA-REC(LL))**M)*COS(J*WA+REC(LL-1))
   20 CONTINUE
      GATT=ATT
      RETURN
      END
