C***********************************************************************
C***********************************************************************
C**
C** INTEGRAL SYSTEMS, INC.
C**
C***********************************************************************
C**
C**   PROJECT : OPERATIONS GROUND EQUIPMENT FOR GOES-NEXT
C**   SYSTEM : EARTH LOCATION USERS GUIDE
C**   ROUTINE : GPOINT
C**   SOURCE : GPOINT.FOR
C**   LOAD NAME : ANY
C**   PROGRAMMER: IGOR LEVINE
C**
C**   VER. DATA BY COMMENT
C** ---- -------- --- ---------------------------------------------
C**   1 12/10/87 IL INITIAL CREATION
C**   2 06/10/88 IL REPLACED ASIN WITH ATAN TO SAVE TIME
C**   3 06/02/89 IL COORDINATE AXES CHANGED ACCORDING TO
C**   FORD'S DEFINITION IN SDAIP, DRL 504-01
C**   4 12/01/93 IL IMPLEMENTED NEW FORMULAE FOR SCAN ANGLE
C**   CORRECTIONS DUE TO MISALIGNMENTS.
C**
C***********************************************************************
C**
C**   THIS SUBROUTINE CONVERTS GEOGRAPHIC LATITUDE AND LONGITUDE
C**   TO THE RELATED ELEVATION AND SCAN ANGLES.
C**
C***********************************************************************
C**
C**   CALLED BY : ANY
C**   COMMONS MODIFIED: NONE
C**   INPUTS : NONE
C**   OUTPUTS : NONE
C**   ROUTINES CALLED : NONE
C**
C***********************************************************************
C***********************************************************************
      SUBROUTINE GPOINT(INSTR,FLIP_FLG,RLAT,RLON,ALF,GAM,IERR)
      IMPLICIT NONE
C
C CALLING PARAMETERS
C
      INTEGER*4 INSTR
C INSTRUMENT CODE (1=IMAGER,2=SOUNDER)
      INTEGER*4 FLIP_FLG
C S/C ORIENTATION FLAG (1=NORMAL,-1=INVERTED)
      REAL*4 RLAT
c GEOGRAPHIC LATITUDE IN RADIANS (INPUT)
      REAL*4 RLON
c GEOGRAPHIC LONGITUDE IN RADIANS (INPUT)
      REAL*4 ALF
c ELEVATION ANGLE IN RADIANS (OUTPUT)
      REAL*4 GAM
c SCAN ANGLE IN RADIANS (OUTPUT)
      INTEGER IERR
c OUTPUT STATUS; 0 - SUCCESSFUL COMPLETION,
c 1 - POINT WITH GIVEN LAT/LON IS INVISIBLE
C
C LOCAL VARIABLES
C
      REAL*8 F(3)
c POINTING VECTOR IN EARTH-CENTERED COORDINATES
      REAL*4 FT(3)
c POINTING VECTOR IN INSTRUMENT COORDINATES
      REAL*4 U(3)
c COORDINATES OF THE EARTH POINT (KM)
      REAL*4 SING,SLAT,W1,W2,FF,DOFF,ALPHA1
C WORK SPACE
C
C INCLUDE FILES
C
      INCLUDE 'ELCONS.INC'
      INCLUDE 'ELCOMM.INC'
      INCLUDE 'INSTCOMM.INC'
C********************************************************************
C
C COMPUTES SINUS OF GEOGRAPHIC (GEODETIC) LATITUDE
C
      write (*, *) INSTR,FLIP_FLG,RLAT,RLON,ALF,GAM,IERR
      SING=SIN(RLAT)
      W1=AEBE4*SING*SING
C
C COMPUTE SIGN OF MISALIGNMENT CORRECTIONS AND ORIGIN OFFSET CORRECTIONS
C
      FF = FLIP_FLG
      IF (INSTR.EQ.2) FF = - FF
            DOFF = SCNMAX(INSTR) - EWNOM(INSTR)
C
C SINUS OF THE GEOCENTRIC LATITUDE
C
      SLAT=((0.375*W1-0.5)*W1+1.)*SING/AEBE2
C
C COMPUTES LOCAL EARTH RADIUS AT SPECIFIED POINT
C
      W2=SLAT*SLAT
      W1=AEBE3*W2
      W1=(0.375*W1-0.5)*W1+1.
C
C COMPUTES CARTESIAN COORDINATES OF THE POINT
C
      U(3)=SLAT*W1
      W2=W1*SQRT(1.-W2)
      U(1)=W2*COS(RLON)
      U(2)=W2*SIN(RLON)
C
C POINTING VECTOR FROM SATELLITE TO THE EARTH POINT
C
      F(1)=U(1)-XS(1)
      F(2)=U(2)-XS(2)
      F(3)=U(3)-XS(3)
      W2=U(1)*SNGL(F(1))+U(2)*SNGL(F(2))+
     1 U(3)*SNGL(F(3))*AEBE2
      write (*, *) W2
C
C VERIFIES VISIBILITY OF THE POINT
C
      IF (W2.GT.0.) THEN
      IERR=1
      ALF=99999.
      GAM=99999.
      RETURN
      END IF
C
C CONVERTS POINTING VECTOR TO INSTRUMENT COORDINATES
C
      FT(1)=BT(1,1)*F(1)+BT(2,1)*F(2)+BT(3,1)*F(3)
      FT(2)=BT(1,2)*F(1)+BT(2,2)*F(2)+BT(3,2)*F(3)
      FT(3)=BT(1,3)*F(1)+BT(2,3)*F(2)+BT(3,3)*F(3)
C
C CONVERTS POINTING VECTOR TO SCAN AND ELEVATION ANGLES AND
C CORRECTS FOR THE ROLL AND PITCH MISALIGNMENTS
C
      GAM=ATAN(FT(1)/SQRT(FT(2)**2+FT(3)**2))
      ALF=-ATAN(FT(2)/FT(3))
      W1=SIN(ALF)
      W2=COS(GAM)
      ALPHA1=ALF+RMA*(1.-COS(ALF)/W2)+PMA*W1*(FF/W2+TAN(GAM))
      GAM=GAM-FF*RMA*W1
      ALF = ALPHA1 + ALPHA1*GAM*DOFF
      GAM = GAM - 0.5*ALPHA1*ALPHA1*DOFF
      IERR=0
      RETURN
      END
