C***********************************************************************
C***********************************************************************
C**
C** INTEGRAL SYSTEMS, INC.
C**
C***********************************************************************
C**
C** PROJECT : OPERATIONS GROUND EQUIPMENT FOR GOES-NEXT
C** SYSTEM : EARTH LOCATION USERS GUIDE
C** ROUTINE : INST2ER
C** SOURCE : INST2ER.FOR
C** LOAD NAME : ANY
C** PROGRAMMER: IGOR LEVINE
C**
C** VER. DATA BY COMMENT
C** ---- -------- --- ---------------------------------------------
C** 1 08/16/88 IL INITIAL CREATION
C** 2 11/11/88 IL TRIGONOMETRIC FUNCTIONS REPLACED WITH
C** SMALL ANGLE APPROXIMATIONS
C** 3 06/02/89 IL COORDINATE AXES CHANGED ACCORDING TO
C** FORD'S DEFINITION IN SDAIP, DRL 504-01
C**
C***********************************************************************
C**
C** INST2ER ACCEPTS THE SINGLE PRECISION ROLL, PITCH AND YAW ANGLES
C** OF AN INSTRUMENT AND RETURNS THE DOUBLE PRECISION INSTRUMENT TO
C** EARTH COORDINATES TRANSFORMATION MATRIX.
C**
C***********************************************************************
C**
C** CALLED BY : ANY
C** COMMONS MODIFIED: NONE
C** INPUTS : NONE
C** OUTPUTS : NONE
C** ROUTINES CALLED : NONE
C**
C***********************************************************************
C***********************************************************************
      SUBROUTINE INST2ER(R,P,Y,A,AT)
      IMPLICIT NONE
C
C CALLING PARAMETERS
C
      REAL*4 R
C ROLL ANGLE IN RADIANS
      REAL*4 P
C PITCH ANGLE IN RADIANS
      REAL*4 Y
C YAW ANGLE IN RADIANS
      REAL*8 A(3,3)
C SPACECRAFT TO ECEF COORDINATES
C TRANSFORMATION MATRIX
      REAL*8 AT(3,3)
C INSTRUMENT TO ECEF COORDINATES
C TRANSFORMATION MATRIX
C
C LOCAL VARIABLES
C
      REAL*8 RPY(3,3)
C INSTRUMENT TO BODY COORDIN
C TRANSFORMATION MATRIX
      REAL SR,CR,SP,CP,SY,CY
      INTEGER*4 I,J
C INDICES
C
C INCLUDE FILES
C
C**********************************************************************
C
C COMPUTE INSTRUMENT TO BODY COORDINATES TRANSFORMATION MATRIX
C
      SP=SIN(P)
      CP=COS(P)
      SR=SIN(R)
      CR=COS(R)
      SY=SIN(Y)
      CY=COS(Y)
      RPY(1,1)=CY*CP
      RPY(2,1)=CY*SP*SR+SY*CR
      RPY(3,1)=SY*SR-CY*SP*CR
      RPY(1,2)=-SY*CP
      RPY(2,2)=CY*CR-SP*SR*SY
      RPY(3,2)=CY*SR+SY*SP*CR
      RPY(1,3)=SP
      RPY(2,3)=-CP*SR
      RPY(3,3)=CP*CR
C
C MULTIPLICATION OF MATRICES A AND RPY
C
      DO 10 I=1,3
      DO 10 J=1,3
   10 AT(I,J)=A(I,1)*RPY(1,J)+A(I,2)*RPY(2,J)+A(I,3)*RPY(3,J)
      RETURN
      END
