C***********************************************************************
C***********************************************************************
C**
C** INTEGRAL SYSTEMS, INC.
C**
C***********************************************************************
C**
C** PROJECT : OPERATIONS GROUND EQUIPMENT FOR GOES-NEXT
C** SYSTEM : EARTH LOCATION USERS GUIDE
C** ROUTINE : SNDELOC
C** SOURCE : SNDELOC.FOR
C** LOAD NAME : ANY
C** PROGRAMMER: IGOR LEVINE
C**
C** VER. DATA BY COMMENT
C** ---- -------- --- ---------------------------------------------
C** 1 02/16/89 IL INITIAL CREATION
C** 2 03/09/90 IL CORRECTED ANGULAR DETECTOR OFFSETS
C***********************************************************************
C**
C** SNDELOC ACCEPTS THE MIRROR POSITION IN CYCLES AND INCREMENTS,
C** SERVO ERROR VALUES, AND THE POSITIONAL OFFSETS FOR FOUR DETECTORS
C** OF A SELECTED SOUNDER CHANNEL AND COMPUTES THE DETECTOR EARTH
C** LOCATIONS IN LATITUDE/LONGITUDE COORDINATES.
C**
C***********************************************************************
C**
C** CALLED BY : ANY
C** COMMONS MODIFIED: NONE
C** INPUTS : NONE
C** OUTPUTS : NONE
C** ROUTINES CALLED : LPOINT
C**
C***********************************************************************
C***********************************************************************
      SUBROUTINE SNDELOC(FLIP, CYEW,INCEW,CYNS,INCNS,SVEW,SVNS,DOFF,GEO)
      IMPLICIT NONE
C
C CALLING PARAMETERS
C
      INTEGER*4 FLIP
C S/C ORIENTATION FLAG (1=NORMAL,-1=INVERTED)
      INTEGER CYEW
C E-W CYCLES
      INTEGER INCEW
C E-W INCREMENTS
      INTEGER CYNS
C N-S CYCLES
      INTEGER INCNS
C N-S INCREMENTS
      REAL*4 SVEW
C E-W SERVO ERROR IN RADIANS
      REAL*4 SVNS
C N-S SERVO ERROR IN RADIANS
      REAL*4 DOFF(4,2)
C OFFSETS FOR 4 DETECTORS (RADIANS)
C DOFF(*,1) = E-W OFFSET
C DOFF(*,2) = N-S OFFSET
C NOTE: OFFSETS ARE GIVEN RELATIVE TO NOMINAL
C POSITIONS OF DETECTORS
      REAL*4 GEO(4,2)
C GEOGRAPHIC COORDINATES RELATED TO 4 DETECTORS
C GEO(*,1) = LATITUDE IN RADIANS
C GEO(*,2) = LONGITUDE IN RADIANS
C
C LOCAL VARIABLES
C
      REAL E,S,H,EV,SC,DE,DS,SINE,COSE
      INTEGER I,IER
C
C INCLUDE FILES
C
      INCLUDE 'INSTCOMM.INC'
C***********************************************************************
C
C CONVERT THE MIRROR POSITION, GIVEN IN CYCLES AND INCREMENTS, TO
C ELEVATION AND SCAN ANGLES
C
      IF (FLIP .EQ. 1) THEN
            E=ELVMAX(2) + ((CYNS-9)*INCMAX(2)+INCNS)*ELVINCR(2) + SVNS
            S=(CYEW*INCMAX(2)+INCEW)*SCNINCR(2)-SCNMAX(2) + SVEW
      ELSE
            E=ELVMAX(2) - (CYNS*INCMAX(2)+INCNS)*ELVINCR(2) - SVNS
            S=((5-CYEW)*INCMAX(2)-INCEW)*SCNINCR(2)-SCNMAX(2) - SVEW
      ENDIF
C
C CORRECT ELEVATION AND SCAN ANGLES FOR SERVO ERRORS OBTAINING THE
C TRUE MIRROR POINTING
C
      SINE=FLIP*SIN(E)
      COSE=COS(E)
      H=-2.*SCNPX(2)
C
C COMPUTE EARTH LOCATIONS FOR FOUR DETECTORS
C
      DO 10 I=1,4
C
C COMPUTE POSITIONAL OFFSETS OF I-TH DETECTOR
C
      DE=(2.5-I)*ELVLN(2)+DOFF(I,2)
      DS=H+DOFF(I,1)
C
C CONVERT POSITIONAL OFFSETS TO ANGULAR OFFSETS AND
C CORRECT ELEVATION AND SCAN ANGLES
C
      EV=E + DE*COSE + DS*SINE
      SC=S - DE*SINE + DS*COSE
C
C TRANSFORM DETECTOR'S POINTING ANGLES TO GEOGRAPHIC COORDINATES
C OF THE CORRESPONDING POINT ON THE EARTH SURFACE.
C NOTE: IF A DETECTOR LOOKS OFF THE EARTH, THE RELATED LATITUDE
C AND LONGITUDE ARE SET TO 999999.
C
      CALL LPOINT(2,FLIP,EV,SC,GEO(I,1),GEO(I,2),IER)
      H=-H
   10 CONTINUE
      RETURN
      END
