C***********************************************************************
C***********************************************************************
C**
C** INTEGRAL SYSTEMS, INC.
C**
C***********************************************************************
C**
C** PROJECT : OPERATIONS GROUND EQUIPMENT FOR GOES-NEXT
C** SYSTEM : EARTH LOCATION USERS GUIDE
C** PROGRAM : TEST
C** SOURCE : TEST.FOR
C** LOAD NAME : ANY
C** PROGRAMMER: IGOR LEVINE
C**
C** VER. DATA BY COMMENT
C** ---- -------- --- ---------------------------------------------
C** 1 10/03/89 IL INITIAL CREATION
C** 2 06/06/94 IL NOW SETCONS IS CALLED WITH 8 ARGUMENTS
C**
C***********************************************************************
C**
C** THIS PROGRAM GENERATES TEST CASES TO VALIDATE THE USER'S
C** IMPLEMENTATIONS OF SOFTWARE FOR TRANSFORMATIONS BETWEEN
C** THE LATITUDE/LONGITUDE AND LINE/PIXEL COORDINAT SYSTEMS.
C** THE RELATED O&A PARAMETER SET IS DEFINED IN INCLUDE FILE I.ELREC.
C**
C***********************************************************************
C**
C** CALLED BY : NONE
C** COMMONS MODIFIED: NONE
C** INPUTS : NONE
C** OUTPUTS : NONE
C** ROUTINES CALLED : SETCONS,LMODEL,EVLN,SCPX,LPOINT,
C** GPOINT,EVSC2LPF,SNDELOC
C**
C***********************************************************************
C***********************************************************************
      PROGRAM TEST
      IMPLICIT NONE
C
C CALLING PARAMETERS
C
C
C LOCAL VARIABLES
C
      REAL*8 T,TIME50,TU,DLAT(2),DLON(2)
      REAL DOFF(4,2),GEO(4,2),RLAT,RLON,E,S,RL,RP,EVLN,SCPX,SVX,SVY
      INTEGER INSTR,IMC,IER,ICX,INCX,ICY,INCY,I,J,FLIP_FLG
C
C INCLUDE FILES
C
      INCLUDE 'ELCONS.INC'
      INCLUDE 'INSTCOMM.INC'
      INCLUDE 'ELCOMM.INC'
      INCLUDE 'ELREC.INC'

      DATA DLAT,DLON/50.,-50.,-150.,-50./
      DATA SVX,SVY/-21.E-6,14.E-6/
      DATA DOFF/28.E-6,56.E-6,-28.E-6,-56.E-6,84.E-6,112.E-6,14.E-6,
     * 42.E-6/
      DATA ICX,INCX,ICY,INCY/1,2715,5,2580/
C***********************************************************************
C
C EXPECTED RESULTS:
C ******** ********
C
C EPOCH TIME = 20557829.57612
C
C NORMAL SPACECRAFT
C
C IMC = 0 (ENABLED) SUBSATELLITE LAT =-1.9824 LON =-100.1249
C
C INSTRUMENT = 1 (IMAGER)
C
C LAT/LON TO LINE/PIXEL TRANSFORMATION:
C LAT = 50.0000 LON =-150.0000
C N-S = 7.0688 E-W =-4.5246
C LINE = 3487.36 PIXEL = 10405.39
C LINE/PIXEL TO LAT/LON TRANSFORMATION:
C LINE = 3487.36 PIXEL = 10405.39
C N-S = 7.0688 E-W =-4.5246
C LAT = 50.0000 LON =-150.0000
C
C INSTRUMENT = 2 (SOUNDER)
C
C LAT/LON TO LINE/PIXEL TRANSFORMATION:
C LAT =-50.0000 LON = -50.0000
C N-S =-6.8659 E-W = 4.5781
C LINE = 1219.41 PIXEL = 1162.87
C LINE/PIXEL TO LAT/LON TRANSFORMATION:
C LINE = 1219.41 PIXEL = 1162.87
C N-S =-6.8659 E-W = 4.5781
C LAT =-50.0000 LON = -50.0000
C
C
C IMC = 1 (DISABLED) SUBSATELLITE LAT = 0.0509 LON =-100.0017
C
C INSTRUMENT = 1 (IMAGER)
C
C LAT/LON TO LINE/PIXEL TRANSFORMATION:
C LAT = 50.0000 LON =-150.0000
C N-S = 6.8594 E-W =-4.6513
C LINE = 3617.92 PIXEL = 10267.15
C LINE/PIXEL TO LAT/LON TRANSFORMATION:
C LINE = 3617.92 PIXEL = 10267.15
C N-S = 6.8594 E-W =-4.6513
C LAT = 49.9999 LON =-149.9997
C
C INSTRUMENT = 2 (SOUNDER)
C
C LAT/LON TO LINE/PIXEL TRANSFORMATION:
C LAT =-50.0000 LON = -50.0000
C N-S =-7.1650 E-W = 4.3902
C LINE = 1238.05 PIXEL = 1151.16
C LINE/PIXEL TO LAT/LON TRANSFORMATION:
C LINE = 1238.05 PIXEL = 1151.16
C N-S =-7.1650 E-W = 4.3902
C LAT =-49.9999 LON = -50.0003
C
C CYCLES/INCREMENTS TO LAT/LON TRANSFORMATION:
C E-W CYCLES/INCREMENTS = 1, 2715
C N-S CYCLES/INCREMENTS = 5, 2580
C E-W SERVO ERROR = -21.00 (mrad)
C N-S SERVO ERROR = 14.00 (mrad)
C
C DETECTOR #1 #2 #3 #4
C E-W OFFSET 28.00 56.00 -28.00 -56.00 (mrad)
C N-S OFFSET 84.00 112.00 14.00 42.00 (mrad)
C
C DETECTOR #1 LAT = 25.1035 LON =-118.8478
C DETECTOR #2 LAT = 25.0270 LON =-118.3774
C DETECTOR #3 LAT = 24.8625 LON =-118.8069
C DETECTOR #4 LAT = 24.7853 LON =-118.3595
C
C FLIPPED (INVERTED SPACECRAFT
C
C IMC = 0 (ENABLED) SUBSATELLITE LAT =-1.9824 LON =-100.1249
C
C INSTRUMENT = 1 (IMAGER)
C
C LAT/LON TO LINE/PIXEL TRANSFORMATION:
C LAT = 50.0000 LON =-150.0000
C N-S = 7.0688 E-W =-4.5246
C LINE = 3487.36 PIXEL = 10405.39
C LINE/PIXEL TO LAT/LON TRANSFORMATION:
C LINE = 3487.36 PIXEL = 10405.39
C N-S = 7.0688 E-W =-4.5246
C LAT = 50.0000 LON =-150.0000
C
C INSTRUMENT = 2 (SOUNDER)
C
C LAT/LON TO LINE/PIXEL TRANSFORMATION:
C LAT =-50.0000 LON = -50.0000
C N-S =-6.8659 E-W = 4.5780
C LINE = 1219.35 PIXEL = 1162.99
C LINE/PIXEL TO LAT/LON TRANSFORMATION:
C LINE = 1219.35 PIXEL = 1162.99
C N-S =-6.8659 E-W = 4.5780
C LAT =-50.0000 LON = -50.0000
C
C
C IMC = 1 (DISABLED) SUBSATELLITE LAT = 0.0509 LON =-100.0017
C
C INSTRUMENT = 1 (IMAGER)
C
C LAT/LON TO LINE/PIXEL TRANSFORMATION:
C LAT = 50.0000 LON =-150.0000
C N-S = 6.8450 E-W =-4.6370
C LINE = 3626.88 PIXEL = 10282.76
C LINE/PIXEL TO LAT/LON TRANSFORMATION:
C LINE = 3626.88 PIXEL = 10282.76
C N-S = 6.8450 E-W =-4.6370
C LAT = 49.9998 LON =-149.9996
C
C INSTRUMENT = 2 (SOUNDER)
C
C LAT/LON TO LINE/PIXEL TRANSFORMATION:
C LAT =-50.0000 LON = -50.0000
C N-S =-7.1800 E-W = 4.4052
C LINE = 1238.93 PIXEL = 1152.22
C LINE/PIXEL TO LAT/LON TRANSFORMATION:
C LINE = 1238.93 PIXEL = 1152.22
C N-S =-7.1800 E-W = 4.4052
C LAT =-49.9998 LON = -50.0003
C
C CYCLES/INCREMENTS TO LAT/LON TRANSFORMATION:
C E-W CYCLES/INCREMENTS = 1, 2715
C N-S CYCLES/INCREMENTS = 5, 2580
C E-W SERVO ERROR = -21.00 (mrad)
C N-S SERVO ERROR = 14.00 (mrad)
C
C DETECTOR #1 #2 #3 #4
C E-W OFFSET 28.00 56.00 -28.00 -56.00 (mrad)
C N-S OFFSET 84.00 112.00 14.00 42.00 (mrad)
C
C DETECTOR #1 LAT =-22.5543 LON = -80.4361
C DETECTOR #2 LAT =-22.6288 LON = -79.9716
C DETECTOR #3 LAT =-22.7889 LON = -80.3995
C DETECTOR #4 LAT =-22.8645 LON = -79.9554
C
C NOTE: LAT, LON, AND N-S, E-W ANGLES ARE IN DEGREES.
C
C***********************************************************************
C SET CONSTANTS IN COMMON INSTCOMM
      CALL SETCONS(4,3068,2,3068,4,1402,2,1402)
C COMPUTE EPOCH TIME
C TU=TIME50(REC(12))
      TU=20557829.57612
      PRINT 500,TU
      T=TU+20.
      DO FLIP_FLG = 1, -1, -2
      DO IMC=0,1
C COMPUTE DATA NEEDED FOR INSTRUMENT TO EARTH COORDINATES
C TRANSFORMATION
      CALL LMODEL(T,TU,REC,IMC,RLAT,RLON)
      PRINT 510,IMC,RLAT*DEG,RLON*DEG
      DO INSTR=1,2
C GEOGRAPHIC TO LINE/PIXEL COORDINATES TRANSFORMATION:
C SET INPUT LATITUDE AND LONGITUDE
      RLAT=DLAT(INSTR)*RAD
      RLON=DLON(INSTR)*RAD
      PRINT 520,INSTR,DLAT(INSTR),DLON(INSTR)
C TRANSFORM LAT/LON TO N-S AND E-W INSTRUMENT ANGLES
      CALL GPOINT(INSTR,FLIP_FLG,RLAT,RLON,E,S,IER)
      IF (IER.EQ.0) THEN
C CONVERT N-S AND E-W ANGLES TO LINE/PIXEL COORDINATES
      CALL EVSC2LPF(INSTR,E,S,RL,RP)
      PRINT 530,E*DEG,S*DEG,RL,RP
C REVERSE TRANSFORMATION: LINE/PIXEL TO GEOGRAPHIC COORDINATES
C CONVERT LINE/PIXEL NUMBERS TO N-S AND E-W INSTRUMENT ANGLES
      E=EVLN(INSTR,RL)
      S=SCPX(INSTR,RP)
      PRINT 540,RL,RP,E*DEG,S*DEG
C TRANSFORM N-S AND E-W ANGLES TO GEOGRAPHIC COORDINATES
      CALL LPOINT(INSTR,FLIP_FLG,E,S,RLAT,RLON,IER)
      IF (IER.EQ.0) PRINT 550,RLAT*DEG,RLON*DEG
      END IF
      ENDDO
      ENDDO
C TRANSFORM CYCLES/INCREMENTS, SERVO ERROR VALUES AND THE
C FACTORY-MEASURED DETECTOR OFFSETS TO LAT/LON COORDINATES
C FOR THE FOUR DETECTORS OF THE SOUNDER INSTRUMENT
      CALL SNDELOC(FLIP_FLG,ICX,INCX,ICY,INCY,SVX,SVY,DOFF,GEO)
      PRINT 560,ICX,INCX,ICY,INCY,SVX*1.E6,SVY*1.E6
      PRINT 570,((DOFF(I,J)*1.E6,I=1,4),J=1,2)
      PRINT 580, (I,GEO(I,1)*DEG,GEO(I,2)*DEG,I=1,4)
      CALL SETCONS(4,3068,2,3068,4,1403,2,1403)
      ENDDO
  500 FORMAT(1X,'EPOCH TIME test =',F15.5)
  510 FORMAT(//1X,'IMC =',I2,3X,'SUBSATELLITE LAT =',
     * F7.4,3X,'LON =',F9.4)
  520 FORMAT(/1X,'INSTRUMENT =',I2/
     * /3X,'LAT/LON TO LINE/PIXEL TRANSFORMATION:'/
     * 5X,'LAT =',F8.4,4X,'LON =',F9.4)
  530 FORMAT(5X,'N-S =',F7.4,5X,'E-W =',F7.4/
     * 5X,'LINE =',F9.2,2X,'PIXEL =',F9.2)
  540 FORMAT(3X,'LINE/PIXEL TO LAT/LON TRANSFORMATION:'/
     * 5X,'LINE =',F9.2,2X,'PIXEL =',F9.2/
     * 5X,'N-S =',F7.4,5X,'E-W =',F7.4)
  550 FORMAT(5X,'LAT =',F8.4,4X,'LON =',F9.4)
  560 FORMAT(/3X,'CYCLES/INCREMENTS TO LAT/LON TRANSFORMATION:'/
     * 5X,'E-W CYCLES/INCREMENTS =',I2,',',I5/
     * 5X,'N-S CYCLES/INCREMENTS =',I2,',',I5/
     * 5X,'E-W SERVO ERROR =',F7.2,' (mrad)'/
     * 5X,'N-S SERVO ERROR =',F7.2,' (mrad)')
  570 FORMAT(/5X,'DETECTOR',6X,'#1',6X,'#2',6X,'#3',6X,'#4'/
     * 5X,'E-W OFFSET',4F8.2,' (mrad)'/
     * 5X,'N-S OFFSET',4F8.2,' (mrad)'/)
  580 FORMAT(5X,'DETECTOR #',I1,3X,'LAT =',F8.4,2X,'LON =',F9.4)
      END
